# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401

from typing import Any, List, Optional
from pydantic import BaseModel, Field, StrictStr, ValidationError, validator
from synctera_client_ng.models.card_fulfillment_status import CardFulfillmentStatus
from synctera_client_ng.models.card_pin_status import CardPinStatus
from synctera_client_ng.models.card_status import CardStatus
from typing import Any, List
from pydantic import StrictStr, Field

CARDCHANGESTATE_ONE_OF_SCHEMAS = ["CardFulfillmentStatus", "CardPinStatus", "CardStatus"]

class CardChangeState(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    # data type: CardFulfillmentStatus
    oneof_schema_1_validator: Optional[CardFulfillmentStatus] = None
    # data type: CardStatus
    oneof_schema_2_validator: Optional[CardStatus] = None
    # data type: CardPinStatus
    oneof_schema_3_validator: Optional[CardPinStatus] = None
    actual_instance: Any
    one_of_schemas: List[str] = Field(CARDCHANGESTATE_ONE_OF_SCHEMAS, const=True)

    class Config:
        validate_assignment = True

    @validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = cls()
        error_messages = []
        match = 0
        # validate data type: CardFulfillmentStatus
        if type(v) is not CardFulfillmentStatus:
            error_messages.append(f"Error! Input type `{type(v)}` is not `CardFulfillmentStatus`")
        else:
            match += 1

        # validate data type: CardStatus
        if type(v) is not CardStatus:
            error_messages.append(f"Error! Input type `{type(v)}` is not `CardStatus`")
        else:
            match += 1

        # validate data type: CardPinStatus
        if type(v) is not CardPinStatus:
            error_messages.append(f"Error! Input type `{type(v)}` is not `CardPinStatus`")
        else:
            match += 1

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into CardChangeState with oneOf schemas: CardFulfillmentStatus, CardPinStatus, CardStatus. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into CardChangeState with oneOf schemas: CardFulfillmentStatus, CardPinStatus, CardStatus. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: dict) -> CardChangeState:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> CardChangeState:
        """Returns the object represented by the json string"""
        instance = cls()
        error_messages = []
        match = 0

        # deserialize data into CardFulfillmentStatus
        try:
            instance.actual_instance = CardFulfillmentStatus.from_json(json_str)
            match += 1
        except ValidationError as e:
            error_messages.append(str(e))
        # deserialize data into CardStatus
        try:
            instance.actual_instance = CardStatus.from_json(json_str)
            match += 1
        except ValidationError as e:
            error_messages.append(str(e))
        # deserialize data into CardPinStatus
        try:
            instance.actual_instance = CardPinStatus.from_json(json_str)
            match += 1
        except ValidationError as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into CardChangeState with oneOf schemas: CardFulfillmentStatus, CardPinStatus, CardStatus. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into CardChangeState with oneOf schemas: CardFulfillmentStatus, CardPinStatus, CardStatus. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is not None:
            return self.actual_instance.to_json()
        else:
            return "null"

    def to_dict(self) -> dict:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is not None:
            return self.actual_instance.to_dict()
        else:
            return dict()

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.dict())

