# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from synctera_client_ng.models.posted_transaction_data import PostedTransactionData

class PostedTransaction(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    created: datetime = Field(..., description="The creation date of the transaction")
    data: PostedTransactionData = ...
    effective_date: datetime = Field(..., description="The \"effective date\" of a transaction. This may be earlier than posted_date in some cases (for example, a transaction that occurs on a Saturday may not be posted until the following Monday, but would have an effective date of Saturday)")
    id: StrictInt = ...
    idemkey: StrictStr = Field(..., description="The idempotency key used when initially creating this transaction.")
    info_only: StrictBool = Field(..., description="Whether or not this transaction represents a purely informational operation or an actual money movement")
    lead_mode: StrictBool = Field(..., description="Whether or not this transaction was created operating in \"lead ledger\" mode")
    posted_date: datetime = Field(..., description="The date the transaction was posted. This is the date any money is considered to be added or removed from an account.")
    reference_id: Optional[StrictStr] = Field(..., description="An external ID provided by the payment network to represent this transaction. This will always be null for internal transfers.")
    status: StrictStr = ...
    subtype: StrictStr = Field(..., description="The specific transaction type. For example, for `ach`, this may be \"outgoing_debit\".")
    tenant: StrictStr = Field(..., description="The tenant associated with this transaction, in the form \"<bankid>_<partnerid>\"")
    transaction_time: datetime = Field(..., description="The time the transaction occurred.")
    type: StrictStr = Field(..., description="The general type of transaction. For example, \"card\" or \"ach\".")
    updated: datetime = Field(..., description="The date the transaction was last updated")
    uuid: StrictStr = Field(..., description="The unique identifier of the transaction.")
    __properties = ["created", "data", "effective_date", "id", "idemkey", "info_only", "lead_mode", "posted_date", "reference_id", "status", "subtype", "tenant", "transaction_time", "type", "updated", "uuid"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PostedTransaction:
        """Create an instance of PostedTransaction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        # set to None if reference_id (nullable) is None
        if self.reference_id is None:
            _dict['reference_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PostedTransaction:
        """Create an instance of PostedTransaction from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PostedTransaction.parse_obj(obj)

        _obj = PostedTransaction.parse_obj({
            "created": obj.get("created"),
            "data": PostedTransactionData.from_dict(obj.get("data")) if obj.get("data") is not None else None,
            "effective_date": obj.get("effective_date"),
            "id": obj.get("id"),
            "idemkey": obj.get("idemkey"),
            "info_only": obj.get("info_only"),
            "lead_mode": obj.get("lead_mode"),
            "posted_date": obj.get("posted_date"),
            "reference_id": obj.get("reference_id"),
            "status": obj.get("status"),
            "subtype": obj.get("subtype"),
            "tenant": obj.get("tenant"),
            "transaction_time": obj.get("transaction_time"),
            "type": obj.get("type"),
            "updated": obj.get("updated"),
            "uuid": obj.get("uuid")
        })
        return _obj

