# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field
from synctera_client_ng.models.disclosure import Disclosure

class DisclosureListAllOf(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    disclosures: List[Disclosure] = Field(..., description="Array of disclosures.")
    __properties = ["disclosures"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DisclosureListAllOf:
        """Create an instance of DisclosureListAllOf from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in disclosures (list)
        _items = []
        if self.disclosures:
            for _item in self.disclosures:
                if _item:
                    _items.append(_item.to_dict())
            _dict['disclosures'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DisclosureListAllOf:
        """Create an instance of DisclosureListAllOf from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DisclosureListAllOf.parse_obj(obj)

        _obj = DisclosureListAllOf.parse_obj({
            "disclosures": [Disclosure.from_dict(_item) for _item in obj.get("disclosures")] if obj.get("disclosures") is not None else None
        })
        return _obj

