# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0.dev5
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from datetime import date

from pydantic import Field, StrictStr, conint

from typing import Optional

from synctera_client_ng.models.cash_pickup import CashPickup
from synctera_client_ng.models.cash_pickup_list import CashPickupList
from synctera_client_ng.models.cash_pickup_patch_request import CashPickupPatchRequest
from synctera_client_ng.models.cash_pickup_post_request import CashPickupPostRequest
from synctera_client_ng.models.cash_pickup_status import CashPickupStatus

from synctera_client_ng.api_client import ApiClient
from synctera_client_ng.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class CashPickupsAlphaApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_cash_pickup(self, cash_pickup_post_request : Annotated[CashPickupPostRequest, Field(..., description="cash pickup to create")], **kwargs) -> CashPickup:  # noqa: E501
        """Create a cash pickup  # noqa: E501

        Create a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_cash_pickup(cash_pickup_post_request, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_post_request: cash pickup to create (required)
        :type cash_pickup_post_request: CashPickupPostRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CashPickup
        """
        kwargs['_return_http_data_only'] = True
        return self.create_cash_pickup_with_http_info(cash_pickup_post_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_cash_pickup_with_http_info(self, cash_pickup_post_request : Annotated[CashPickupPostRequest, Field(..., description="cash pickup to create")], **kwargs):  # noqa: E501
        """Create a cash pickup  # noqa: E501

        Create a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_cash_pickup_with_http_info(cash_pickup_post_request, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_post_request: cash pickup to create (required)
        :type cash_pickup_post_request: CashPickupPostRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CashPickup, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'cash_pickup_post_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_cash_pickup" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['cash_pickup_post_request']:
            _body_params = _params['cash_pickup_post_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '201': "CashPickup",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '409': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/cash_pickups', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_cash_pickup(self, cash_pickup_id : Annotated[StrictStr, Field(..., description="The unique identifier of a cash pickup")], **kwargs) -> CashPickup:  # noqa: E501
        """Get a cash pickup  # noqa: E501

        Get a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_cash_pickup(cash_pickup_id, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_id: The unique identifier of a cash pickup (required)
        :type cash_pickup_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CashPickup
        """
        kwargs['_return_http_data_only'] = True
        return self.get_cash_pickup_with_http_info(cash_pickup_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_cash_pickup_with_http_info(self, cash_pickup_id : Annotated[StrictStr, Field(..., description="The unique identifier of a cash pickup")], **kwargs):  # noqa: E501
        """Get a cash pickup  # noqa: E501

        Get a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_cash_pickup_with_http_info(cash_pickup_id, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_id: The unique identifier of a cash pickup (required)
        :type cash_pickup_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CashPickup, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'cash_pickup_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cash_pickup" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['cash_pickup_id']:
            _path_params['cash_pickup_id'] = _params['cash_pickup_id']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CashPickup",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/cash_pickups/{cash_pickup_id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_cash_pickups(self, account_id : Annotated[Optional[StrictStr], Field(description="the account id")] = None, from_date : Annotated[Optional[date], Field(description="the biginning of the time window to search for")] = None, to_date : Annotated[Optional[date], Field(description="the ending of the time window to search for")] = None, status : Annotated[Optional[CashPickupStatus], Field(description="the status of the request")] = None, employee_customer_id : Annotated[Optional[StrictStr], Field(description="the Id of the customer who created the cash pickup request")] = None, business_id : Annotated[Optional[StrictStr], Field(description="the Id of bussiness to search for")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs) -> CashPickupList:  # noqa: E501
        """List cash pickups  # noqa: E501

        Get paginated list of cash pickups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_cash_pickups(account_id, from_date, to_date, status, employee_customer_id, business_id, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param account_id: the account id
        :type account_id: str
        :param from_date: the biginning of the time window to search for
        :type from_date: date
        :param to_date: the ending of the time window to search for
        :type to_date: date
        :param status: the status of the request
        :type status: CashPickupStatus
        :param employee_customer_id: the Id of the customer who created the cash pickup request
        :type employee_customer_id: str
        :param business_id: the Id of bussiness to search for
        :type business_id: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CashPickupList
        """
        kwargs['_return_http_data_only'] = True
        return self.list_cash_pickups_with_http_info(account_id, from_date, to_date, status, employee_customer_id, business_id, limit, page_token, **kwargs)  # noqa: E501

    @validate_arguments
    def list_cash_pickups_with_http_info(self, account_id : Annotated[Optional[StrictStr], Field(description="the account id")] = None, from_date : Annotated[Optional[date], Field(description="the biginning of the time window to search for")] = None, to_date : Annotated[Optional[date], Field(description="the ending of the time window to search for")] = None, status : Annotated[Optional[CashPickupStatus], Field(description="the status of the request")] = None, employee_customer_id : Annotated[Optional[StrictStr], Field(description="the Id of the customer who created the cash pickup request")] = None, business_id : Annotated[Optional[StrictStr], Field(description="the Id of bussiness to search for")] = None, limit : Optional[conint(strict=True, ge=1)] = None, page_token : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """List cash pickups  # noqa: E501

        Get paginated list of cash pickups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_cash_pickups_with_http_info(account_id, from_date, to_date, status, employee_customer_id, business_id, limit, page_token, async_req=True)
        >>> result = thread.get()

        :param account_id: the account id
        :type account_id: str
        :param from_date: the biginning of the time window to search for
        :type from_date: date
        :param to_date: the ending of the time window to search for
        :type to_date: date
        :param status: the status of the request
        :type status: CashPickupStatus
        :param employee_customer_id: the Id of the customer who created the cash pickup request
        :type employee_customer_id: str
        :param business_id: the Id of bussiness to search for
        :type business_id: str
        :param limit:
        :type limit: int
        :param page_token:
        :type page_token: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CashPickupList, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'account_id',
            'from_date',
            'to_date',
            'status',
            'employee_customer_id',
            'business_id',
            'limit',
            'page_token'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_cash_pickups" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('account_id') is not None:  # noqa: E501
            _query_params.append(('account_id', _params['account_id']))
        if _params.get('from_date') is not None:  # noqa: E501
            _query_params.append(('from_date', _params['from_date']))
        if _params.get('to_date') is not None:  # noqa: E501
            _query_params.append(('to_date', _params['to_date']))
        if _params.get('status') is not None:  # noqa: E501
            _query_params.append(('status', _params['status']))
        if _params.get('employee_customer_id') is not None:  # noqa: E501
            _query_params.append(('employee_customer_id', _params['employee_customer_id']))
        if _params.get('business_id') is not None:  # noqa: E501
            _query_params.append(('business_id', _params['business_id']))
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))
        if _params.get('page_token') is not None:  # noqa: E501
            _query_params.append(('page_token', _params['page_token']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CashPickupList",
            '401': "Error",
            '403': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/cash_pickups', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def patch_cash_pickup(self, cash_pickup_id : Annotated[StrictStr, Field(..., description="The unique identifier of a cash pickup")], cash_pickup_patch_request : Annotated[CashPickupPatchRequest, Field(..., description="cash pickup to update")], **kwargs) -> CashPickup:  # noqa: E501
        """Update a cash pickup  # noqa: E501

        Update a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_cash_pickup(cash_pickup_id, cash_pickup_patch_request, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_id: The unique identifier of a cash pickup (required)
        :type cash_pickup_id: str
        :param cash_pickup_patch_request: cash pickup to update (required)
        :type cash_pickup_patch_request: CashPickupPatchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CashPickup
        """
        kwargs['_return_http_data_only'] = True
        return self.patch_cash_pickup_with_http_info(cash_pickup_id, cash_pickup_patch_request, **kwargs)  # noqa: E501

    @validate_arguments
    def patch_cash_pickup_with_http_info(self, cash_pickup_id : Annotated[StrictStr, Field(..., description="The unique identifier of a cash pickup")], cash_pickup_patch_request : Annotated[CashPickupPatchRequest, Field(..., description="cash pickup to update")], **kwargs):  # noqa: E501
        """Update a cash pickup  # noqa: E501

        Update a cash pickup  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.patch_cash_pickup_with_http_info(cash_pickup_id, cash_pickup_patch_request, async_req=True)
        >>> result = thread.get()

        :param cash_pickup_id: The unique identifier of a cash pickup (required)
        :type cash_pickup_id: str
        :param cash_pickup_patch_request: cash pickup to update (required)
        :type cash_pickup_patch_request: CashPickupPatchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CashPickup, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'cash_pickup_id',
            'cash_pickup_patch_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_cash_pickup" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['cash_pickup_id']:
            _path_params['cash_pickup_id'] = _params['cash_pickup_id']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['cash_pickup_patch_request']:
            _body_params = _params['cash_pickup_patch_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/problem+json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CashPickup",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '404': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/cash_pickups/{cash_pickup_id}', 'PATCH',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))
